@@ -1,4 +1,4 @@
 from .mario import Mario, run
 from .mario_GUI import MarioWindow
-from .pygame_mario import PygameMario, ACC_EVENT, RGB_EVENT, PANTS_EVENT
+from .pygame_mario import PygameMario, AsyncClock, ACC_EVENT, RGB_EVENT, PANTS_EVENT
 from .lego_mario_data import *
\ No newline at end of file
